@@ -1,4 +1,4 @@
-from . import fid, kid, inception_score
+from . import fid, kid, inception_score, inception_model
 from .compute_fid import *
 from .compute_is import *
 from .compute_kid import *
